@@ -318,16 +318,19 @@ class AppGui:
                 json.dump(source, target)
             else:
                 target.write(source)
-        # Show the save status to the user.
-        self.saved_status = "saved"
-        self.update_locked_field(self.esavedone, self.saved_status)
         # Normally, the application stores the screenshot files into the working directory,
         # but if we save the workflow data elsewhere, we want to move the PNGs and JSONs
         # to that new location and not leave them in the working directory.
-        for png in glob.glob('./*.png'):
-            shutil.move(png, os.path.join(self.choices['path'], png))
-        for needle in glob.glob('./*.json'):
-            shutil.move(needle, os.path.join(self.choices['path'], needle))
+        # However, if we have already saved, the files have been moved, so we will only
+        # do this, if we have not saved.
+        if self.saved_status != "saved":
+            for png in glob.glob('./*.png'):
+                shutil.move(png, os.path.join(self.choices['path'], png))
+            for needle in glob.glob('./*.json'):
+                shutil.move(needle, os.path.join(self.choices['path'], needle))
+        # Show the save status to the user.
+        self.saved_status = "saved"
+        self.update_locked_field(self.esavedone, self.saved_status)
 
     def set_inputfile(self):
         """ Use filedialog to get the path and name of the input file. """
