@@ -95,7 +95,17 @@ class Interpreter:
             "m":"^",
             ",":"<",
             ".":">",
-            "-":"*"
+            "-":"*",
+            "+":"!",
+            "ě":"@",
+            "š":"#",
+            "č":"$",
+            "ř":"%",
+            "ž":"^",
+            "ý":"&",
+            "á":"*",
+            "í":"{",
+            "é":"}",
         }
 
 
