@@ -1,6 +1,6 @@
 import sched
 import time
-import pyscreenshot
+import mss
 import queue
 import threading
 
@@ -8,14 +8,25 @@ QUEUE = queue.Queue()
 FPS = 10 # I could reasonably get to around 15-20 before taking the screenshot takes too long to keep up with the pace
 BUF_SEC = 1
 BUFFER = [(None, None)] * max(int(FPS * BUF_SEC), 3)
+TAKE_SCREENSHOT = True
 
-def start():
+def start(q = None):
     """ Starts the methods taking care of communication with outside (main_thread)
     and continuously buffering screenhots (sceen_stream) "in background"
     The daemon=True makes sure the threads are killed when the program is terminated
     """
-    threading.Thread(target=main_thread, daemon=True).start()
+    global QUEUE
+    if q:
+        QUEUE = q
+
     threading.Thread(target=screen_stream, daemon=True).start()
+    main_thread(QUEUE)
+
+def no_grab():
+    QUEUE.put(('pause', None))
+
+def do_grab():
+    QUEUE.put(('resume', None))
 
 def save_screenshot(timestamp, delay=None):
     """ A simple wrapper function so the code using the library can be oblivious
@@ -44,7 +55,7 @@ def save_now(timestamp):
         del(bfr_dict[None])
     key = sorted([(abs(k-timestamp), k) for k in bfr_dict.keys() if k <= timestamp])[0][1]
     img = bfr_dict[key]
-    img.save("%s.png" % timestamp)
+    mss.tools.to_png(img.rgb, img.size, output="%s.png" % timestamp)
 
 def save_delay(timestamp):
     """Uses the python's sched library to postpone execution of `save_now` until ${timestamp}
@@ -54,16 +65,18 @@ def save_delay(timestamp):
     s.run()
 
 def screen_stream():
-    """Continuously takes screenshots using the pyscreenshot library, and stores 
+    """Continuously takes screenshots using the pyscreenshot library, and stores
     them in a memory, to be used later on. The buffer is kept to its defined length.
     """
-    while True:
-        ts = time.time()
-        BUFFER.append((ts, pyscreenshot.grab()))
-        del(BUFFER[0])
-        time.sleep(1.0/FPS)
+    with mss.mss() as sct:
+        while True:
+            ts = time.time()
+            if TAKE_SCREENSHOT:
+                BUFFER.append((ts, sct.grab(sct.monitors[0])   ))
+                del(BUFFER[0])
+            time.sleep(1.0/FPS)
 
-def main_thread():
+def main_thread(q):
     """To make the `save_screenshot` call take as little time as possible,
     we are using a Queue filled with either "save" or "delay" requests.
     When a request is added to the Queue, a new thread is spawned to perform the action.
@@ -72,13 +85,17 @@ def main_thread():
 
     On top of that, we have an easy way of scheduling 'delayed' screenshots too.
     """
+    global TAKE_SCREENSHOT
     while True:
-        action, timestamp = QUEUE.get()
+        action, timestamp = q.get()
         if action == 'save':
             threading.Thread(target=save_now, args=(timestamp,), daemon=True).start()
         elif action == 'delay':
             threading.Thread(target=save_delay, args=(timestamp,), daemon=True).start()
-
+        elif action == 'pause':
+            TAKE_SCREENSHOT = False
+        elif action == 'resume':
+            TAKE_SCREENSHOT = True
 
 if __name__ == "__main__":
     start()
